@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2011-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -24,18 +24,28 @@ from contextlib import suppress
 from datetime import datetime
 from lazr.config import as_timedelta
 from mailman.app.lifecycle import create_list
+from mailman.app.membership import delete_member
 from mailman.app.subscriptions import SubscriptionWorkflow
 from mailman.config import config
 from mailman.interfaces.address import InvalidEmailAddressError
 from mailman.interfaces.bans import IBanManager
 from mailman.interfaces.mailinglist import SubscriptionPolicy
 from mailman.interfaces.member import (
-    DeliveryMode, DeliveryStatus, MemberRole, MembershipIsBannedError)
+    AlreadySubscribedError,
+    DeliveryMode,
+    DeliveryStatus,
+    MemberRole,
+    MembershipIsBannedError,
+)
 from mailman.interfaces.pending import IPendings
-from mailman.interfaces.subscriptions import TokenOwner
+from mailman.interfaces.subscriptions import ISubscriptionManager, TokenOwner
 from mailman.interfaces.usermanager import IUserManager
 from mailman.testing.helpers import (
-    LogFileMark, get_queue_messages, set_preferred)
+    configuration,
+    get_queue_messages,
+    LogFileMark,
+    set_preferred,
+)
 from mailman.testing.layers import ConfigLayer
 from mailman.utilities.datetime import now
 from unittest.mock import patch
@@ -197,6 +207,42 @@ class TestSubscriptionWorkflow(unittest.TestCase):
         workflow = SubscriptionWorkflow(self._mlist, user)
         self.assertRaises(AssertionError, workflow.run_thru, 'sanity_checks')
 
+    def test_sanity_checks_finds_address_for_user(self):
+        # Test raises AlreadySubscribedError for User when member is Address.
+        anne = self._user_manager.make_user(self._anne)
+        anne.addresses[0].verified_on = anne.created_on
+        anne.preferred_address = anne.addresses[0]
+        self._mlist.subscription_policy = SubscriptionPolicy.open
+        # Subscribe Address.
+        ISubscriptionManager(self._mlist).register(
+            anne.preferred_address,
+            pre_verified=True,
+            pre_confirmed=True,
+            pre_approved=True,
+            send_welcome_message=False
+            )
+        workflow = SubscriptionWorkflow(self._mlist, anne)
+        self.assertRaises(
+            AlreadySubscribedError, workflow.run_thru, 'sanity_checks')
+
+    def test_sanity_checks_finds_user_for_address(self):
+        # Test raises AlreadySubscribedError for Address when member is User.
+        anne = self._user_manager.make_user(self._anne)
+        anne.addresses[0].verified_on = anne.created_on
+        anne.preferred_address = anne.addresses[0]
+        self._mlist.subscription_policy = SubscriptionPolicy.open
+        # Subscribe User.
+        ISubscriptionManager(self._mlist).register(
+            anne,
+            pre_verified=True,
+            pre_confirmed=True,
+            pre_approved=True,
+            send_welcome_message=False
+            )
+        workflow = SubscriptionWorkflow(self._mlist, anne.preferred_address)
+        self.assertRaises(
+            AlreadySubscribedError, workflow.run_thru, 'sanity_checks')
+
     def test_sanity_checks_globally_banned_address(self):
         # An exception is raised if the address is globally banned.
         anne = self._user_manager.create_address(self._anne)
@@ -381,7 +427,7 @@ class TestSubscriptionWorkflow(unittest.TestCase):
         self.assertEqual(workflow.token_owner, TokenOwner.no_one)
 
     def test_do_subscription_pre_approved(self):
-        # An moderation-requiring subscription policy plus a pre-verified and
+        # A moderation-requiring subscription policy plus a pre-verified and
         # pre-approved address means the user gets subscribed to the mailing
         # list without any further confirmations or approvals.
         self._mlist.subscription_policy = SubscriptionPolicy.moderate
@@ -400,7 +446,7 @@ class TestSubscriptionWorkflow(unittest.TestCase):
         self.assertEqual(workflow.token_owner, TokenOwner.no_one)
 
     def test_do_subscription_pre_approved_pre_confirmed(self):
-        # An moderation-requiring subscription policy plus a pre-verified and
+        # A moderation-requiring subscription policy plus a pre-verified and
         # pre-approved address means the user gets subscribed to the mailing
         # list without any further confirmations or approvals.
         self._mlist.subscription_policy = (
@@ -589,6 +635,21 @@ approval:
         # one token still in the database.
         self._expected_pendings_count = 1
 
+    def test_invitation_verp_confirmations_no(self):
+        # Test From: and Subject: with verp_confirmations equal no.
+        anne = self._user_manager.create_address(self._anne)
+        self.assertIsNone(anne.verified_on)
+        # Run the workflow to model the confirmation step.
+        workflow = SubscriptionWorkflow(self._mlist, anne, invitation=True)
+        with configuration('mta', verp_confirmations='no'):
+            list(workflow)
+        items = get_queue_messages('virgin', expected_count=1)
+        message = items[0].msg
+        token = workflow.token
+        self.assertEqual(f'confirm {token}', str(message['Subject']))
+        self.assertEqual('test-request@example.com', message['From'])
+        self._expected_pendings_count = 1
+
     def test_send_confirmation_pre_confirmed(self):
         # A confirmation message gets sent when the address is not verified
         # but the subscription is pre-confirmed.
@@ -609,6 +670,21 @@ approval:
         # one token still in the database.
         self._expected_pendings_count = 1
 
+    def test_confirmation_subscribe_verp_confirmations_no(self):
+        # Test From: and Subject: with verp_confirmations equal no.
+        anne = self._user_manager.create_address(self._anne)
+        self.assertIsNone(anne.verified_on)
+        # Run the workflow to model the confirmation step.
+        workflow = SubscriptionWorkflow(self._mlist, anne, pre_confirmed=True)
+        with configuration('mta', verp_confirmations='no'):
+            list(workflow)
+        items = get_queue_messages('virgin', expected_count=1)
+        message = items[0].msg
+        token = workflow.token
+        self.assertEqual(f'confirm {token}', str(message['Subject']))
+        self.assertEqual('test-request@example.com', message['From'])
+        self._expected_pendings_count = 1
+
     def test_send_confirmation_pre_verified(self):
         # A confirmation message gets sent even when the address is verified
         # when the subscription must be confirmed.
@@ -854,3 +930,34 @@ approval:
         self.assertEqual(
             anne_member.delivery_mode, DeliveryMode.plaintext_digests)
         self.assertEqual(anne_member.delivery_status, DeliveryStatus.by_user)
+
+    def test_translated_subject_your_confirmation_is_needed(self):
+        anne = self._user_manager.create_user(self._anne)
+        old_language = self._mlist.preferred_language.code
+        self._mlist.preferred_language.code = 'fr'
+        anne_address = anne.addresses[0]
+        workflow = SubscriptionWorkflow(
+            self._mlist, anne_address, pre_verified=True,
+            send_welcome_message=False, delivery_status=DeliveryStatus.by_user)
+        list(workflow)
+        confirm_workflow = SubscriptionWorkflow(self._mlist)
+        confirm_workflow.token = workflow.token
+        confirm_workflow.restore()
+        list(confirm_workflow)
+        self._mlist.preferred_language.code = old_language
+        items = get_queue_messages('virgin', expected_count=1)
+        self.assertEqual(items[0].msg['Subject'], "Votre "
+                         "confirmation est nécessaire pour vous abonner à "
+                         "la liste de diffusion test@example.com.")
+
+    def test_translated_subject_unsubscribe(self):
+        anne = self._user_manager.create_user(self._anne)
+        set_preferred(anne)
+        old_code = anne.preferences.preferred_language
+        anne.preferences.preferred_language = 'fr'
+        self._mlist.subscribe(anne, send_welcome_message=False)
+        delete_member(self._mlist, self._anne, False, True)
+        anne.preferences.preferred_language = old_code
+        items = get_queue_messages('virgin', expected_count=1)
+        self.assertEqual(str(items[0].msg['Subject']), "Vous avez"
+                         " été désabonné de la liste de diffusion Test")
