@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2009-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -47,7 +47,7 @@ def unshunt(discard):
             if not discard:
                 config.switchboards[which_queue].enqueue(msg, msgdata)
         except Exception as error:                             # noqa: F841
-            print(_('Cannot unshunt message $filebase, skipping:\n$error'),
+            print(_('Cannot unshunt message ${filebase}, skipping:\n${error}'),
                   file=sys.stderr)
         else:
             # Unlink the .bak file left by dequeue()
