@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -20,7 +20,7 @@
 import re
 
 from contextlib import suppress
-from email.header import Header, decode_header, make_header
+from email.header import decode_header, Header, make_header
 from mailman.core.i18n import _
 from mailman.interfaces.handler import IHandler
 from public import public
@@ -107,6 +107,8 @@ def all_same_charset(mlist, msgdata, subject, prefix, prefix_pattern, ws):
         first_line.insert(0, recolon)
     if prefix:
         first_line.insert(0, prefix)
+    if len(lines) > 1:
+        first_line.extend(lines[1:])
     subject_text = EMPTYSTRING.join(first_line)
     return Header(subject_text, charset=list_charset, continuation_ws=ws)
 
