@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2020 by the Free Software Foundation, Inc.
+# Copyright (C) 2011-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -26,8 +26,13 @@ from mailman.interfaces.address import InvalidEmailAddressError
 from mailman.interfaces.autorespond import IAutoResponseSet, Response
 from mailman.interfaces.domain import IDomainManager
 from mailman.interfaces.listmanager import (
-    IListManager, ListAlreadyExistsError, ListCreatedEvent, ListCreatingEvent,
-    ListDeletedEvent, ListDeletingEvent)
+    IListManager,
+    ListAlreadyExistsError,
+    ListCreatedEvent,
+    ListCreatingEvent,
+    ListDeletedEvent,
+    ListDeletingEvent,
+)
 from mailman.interfaces.mailinglist import IListArchiverSet
 from mailman.interfaces.messages import IMessageStore
 from mailman.interfaces.pending import IPendable, IPendings
@@ -36,7 +41,9 @@ from mailman.interfaces.subscriptions import ISubscriptionService
 from mailman.interfaces.usermanager import IUserManager
 from mailman.model.mime import ContentFilter
 from mailman.testing.helpers import (
-    event_subscribers, specialized_message_from_string)
+    event_subscribers,
+    specialized_message_from_string,
+)
 from mailman.testing.layers import ConfigLayer
 from zope.component import getUtility
 from zope.interface import implementer
