@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -23,19 +23,43 @@ from mailman.interfaces.action import Action
 from mailman.interfaces.address import IAddress, InvalidEmailAddressError
 from mailman.interfaces.listmanager import IListManager
 from mailman.interfaces.member import (
-    AlreadySubscribedError, DeliveryMode, DeliveryStatus, MemberRole,
-    MembershipError, MembershipIsBannedError, MissingPreferredAddressError)
+    AlreadySubscribedError,
+    DeliveryMode,
+    DeliveryStatus,
+    MemberRole,
+    MembershipError,
+    MembershipIsBannedError,
+    MissingPreferredAddressError,
+)
 from mailman.interfaces.subscriptions import (
-    ISubscriptionManager, ISubscriptionService, RequestRecord,
-    SubscriptionPendingError, TokenOwner)
+    ISubscriptionManager,
+    ISubscriptionService,
+    RequestRecord,
+    SubscriptionPendingError,
+    TokenOwner,
+)
 from mailman.interfaces.user import IUser, UnverifiedAddressError
 from mailman.interfaces.usermanager import IUserManager
 from mailman.rest.helpers import (
-    CollectionMixin, NotFound, accepted, bad_request, child, conflict,
-    created, etag, no_content, not_found, okay)
+    accepted,
+    bad_request,
+    child,
+    CollectionMixin,
+    conflict,
+    created,
+    etag,
+    no_content,
+    not_found,
+    NotFound,
+    okay,
+)
 from mailman.rest.preferences import Preferences, ReadOnlyPreferences
 from mailman.rest.validator import (
-    Validator, enum_validator, list_of_strings_validator, subscriber_validator)
+    enum_validator,
+    list_of_strings_validator,
+    subscriber_validator,
+    Validator,
+)
 from operator import attrgetter
 from public import public
 from uuid import UUID
@@ -61,6 +85,10 @@ class _MemberBase(CollectionMixin):
         # issue #121 for details.
         return {
             'address': self._get_address,
+            'bounce_score': attrgetter('bounce_score'),
+            'last_bounce_received': attrgetter('last_bounce_received'),
+            'last_warning_sent': attrgetter('last_warning_sent'),
+            'total_warnings_sent': attrgetter('total_warnings_sent'),
             'delivery_mode': attrgetter('delivery_mode'),
             'email': attrgetter('address.email'),
             'list_id': attrgetter('list_id'),
