@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -23,13 +23,16 @@ from mailman.app.lifecycle import create_list
 from mailman.database.transaction import transaction
 from mailman.interfaces.digests import DigestFrequency
 from mailman.interfaces.mailinglist import (
-    IAcceptableAliasSet, SubscriptionPolicy)
+    IAcceptableAliasSet,
+    SubscriptionPolicy,
+)
 from mailman.interfaces.template import ITemplateManager
 from mailman.testing.helpers import call_api
 from mailman.testing.layers import RESTLayer
 from urllib.error import HTTPError
 from zope.component import getUtility
 
+
 # The representation of the listconf resource as a dictionary.  This is used
 # when PUTting to the list's configuration resource.
 RESOURCE = dict(
