@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -20,10 +20,11 @@
 import os
 import unittest
 
-from contextlib import ExitStack
+from contextlib import ExitStack, redirect_stderr
 from datetime import datetime, timedelta
 from enum import Enum
 from importlib_resources import open_binary
+from io import StringIO
 from mailman.app.lifecycle import create_list
 from mailman.config import config
 from mailman.database.helpers import is_mysql
@@ -37,7 +38,10 @@ from mailman.interfaces.bounce import UnrecognizedBounceDisposition
 from mailman.interfaces.domain import IDomainManager
 from mailman.interfaces.languages import ILanguageManager
 from mailman.interfaces.mailinglist import (
-    DMARCMitigateAction, IAcceptableAliasSet, SubscriptionPolicy)
+    DMARCMitigateAction,
+    IAcceptableAliasSet,
+    SubscriptionPolicy,
+)
 from mailman.interfaces.member import DeliveryMode, DeliveryStatus
 from mailman.interfaces.nntp import NewsgroupModeration
 from mailman.interfaces.template import ITemplateLoader, ITemplateManager
@@ -48,7 +52,10 @@ from mailman.testing.layers import ConfigLayer
 from mailman.utilities.filesystem import makedirs
 from mailman.utilities.i18n import search
 from mailman.utilities.importer import (
-    Import21Error, check_language_code, import_config_pck)
+    check_language_code,
+    Import21Error,
+    import_config_pck,
+)
 from pickle import load
 from shutil import rmtree
 from unittest import mock
@@ -338,45 +345,54 @@ class TestBasicImport(unittest.TestCase):
         # This used to be a plain-text field (values are newline-separated)
         # but values were interpreted as regexps even without '^' so we need
         # to add the '^'.
+        # Also check that the list name local part is added.
         aliases = ['alias1@example.com',
                    'alias2@exemple.com',
                    'non-ascii-\xe8@example.com',
                    ]
+        new_aliases = ['^alias1@example.com',
+                       '^alias2@exemple.com',
+                       '^blank@',
+                       '^non-ascii-\xe8@example.com',
+                       ]
         self._pckdict['acceptable_aliases'] = list_to_string(aliases)
         self._import()
         alias_set = IAcceptableAliasSet(self._mlist)
-        self.assertEqual(sorted(alias_set.aliases),
-                         [('^' + alias) for alias in aliases])
+        self.assertEqual(sorted(alias_set.aliases), new_aliases)
 
     def test_acceptable_aliases_invalid(self):
         # Values without an '@' sign used to be matched against the local
         # part, now we need to add the '^' sign to indicate it's a regexp.
         aliases = ['invalid-value']
+        new_aliases = ['^blank@', '^invalid-value']
         self._pckdict['acceptable_aliases'] = list_to_string(aliases)
         self._import()
         alias_set = IAcceptableAliasSet(self._mlist)
-        self.assertEqual(sorted(alias_set.aliases),
-                         [('^' + alias) for alias in aliases])
+        self.assertEqual(sorted(alias_set.aliases), new_aliases)
 
     def test_acceptable_aliases_as_list(self):
         # In some versions of the pickle, this can be a list, not a string
         # (seen in the wild).  We still need to add the '^'.
         aliases = [b'alias1@example.com', b'alias2@exemple.com']
+        new_aliases = ['^alias1@example.com', '^alias2@exemple.com', '^blank@']
         self._pckdict['acceptable_aliases'] = aliases
         self._import()
         alias_set = IAcceptableAliasSet(self._mlist)
-        self.assertEqual(sorted(alias_set.aliases),
-                         sorted(('^' + a.decode('utf-8')) for a in aliases))
+        self.assertEqual(sorted(alias_set.aliases), new_aliases)
 
     def test_dont_add_caret_if_present(self):
         # The 2.1 alias could have had a leading '^' even though not required.
         aliases = ['^alias1@example.com',
                    '^alias2@.*',
                    ]
+        new_aliases = ['^alias1@example.com',
+                       '^alias2@.*',
+                       '^blank@',
+                       ]
         self._pckdict['acceptable_aliases'] = list_to_string(aliases)
         self._import()
         alias_set = IAcceptableAliasSet(self._mlist)
-        self.assertEqual(sorted(alias_set.aliases), aliases)
+        self.assertEqual(sorted(alias_set.aliases), new_aliases)
 
     def test_info_non_ascii(self):
         # info can contain non-ascii characters.
@@ -823,8 +839,8 @@ class TestConvertToURI(unittest.TestCase):
     def test_substitutions(self):
         test_text = ('UNIT TESTING %(real_name)s mailing list\n'
                      '%(real_name)s@%(host_name)s')
-        expected_text = ('UNIT TESTING $display_name mailing list '
-                         '-- $listname\n'
+        expected_text = ('UNIT TESTING ${display_name} mailing list '
+                         '-- ${listname}\n'
                          'To unsubscribe send an email to '
                          '${short_listname}-leave@${domain}')
         for oldvar, newvar in self._conf_mapping.items():
@@ -835,6 +851,85 @@ class TestConvertToURI(unittest.TestCase):
                 text, expected_text,
                 'Old variables were not converted for %s' % newvar)
 
+    def test_more_substitutions(self):
+        test_text = ('UNIT TESTING %(real_name)s some list\n'
+                     'The listname is %(list_name)s\n'
+                     'The description is %(description)s\n'
+                     'Info is %(info)s\n'
+                     'User address to is %(user_address)s\n'
+                     'User delivered is %(user_delivered_to)s\n'
+                     'User password: %(user_password)s\n'
+                     'User name %(user_name)s\n')
+        expected_text = ('UNIT TESTING ${display_name} some list\n'
+                         'The listname is ${listname}\n'
+                         'The description is ${description}\n'
+                         'Info is ${info}\n'
+                         'User address to is ${user_email}\n'
+                         'User delivered is ${user_delivered_to}\n'
+                         'User password: \n'
+                         'User name ${user_name}\n')
+        for oldvar, newvar in self._conf_mapping.items():
+            self._pckdict[str(oldvar)] = str(test_text)
+            import_config_pck(self._mlist, self._pckdict)
+            text = getUtility(ITemplateLoader).get(newvar, self._mlist)
+            self.assertEqual(
+                text, expected_text,
+                'Old variables were not converted for %s' % newvar)
+
+    def test_cgiext_dropped(self):
+        test_text = ('UNIT TESTING %(real_name)s mailing list\n'
+                     'https://example.com/mailman/listinfo%(cgiext)s')
+        expected_text = ('UNIT TESTING ${display_name} mailing list '
+                         '-- ${listname}\n'
+                         'https://example.com/mailman/listinfo')
+        for oldvar, newvar in self._conf_mapping.items():
+            self._pckdict[str(oldvar)] = str(test_text)
+            import_config_pck(self._mlist, self._pckdict)
+            text = getUtility(ITemplateLoader).get(newvar, self._mlist)
+            self.assertEqual(
+                text, expected_text,
+                'Old variables were not converted for %s' % newvar)
+
+    def test_unconverted_issues_message(self):
+        test_text = ('UNIT TESTING %(real_name)s mailing list\n'
+                     '%(web_page_url)slistinfo/')
+        expected_text = ('UNIT TESTING ${display_name} mailing list '
+                         '-- ${listname}\n'
+                         '%(web_page_url)slistinfo/')
+        for oldvar, newvar in self._conf_mapping.items():
+            serr = StringIO()
+            with redirect_stderr(serr):
+                self._pckdict[str(oldvar)] = str(test_text)
+                import_config_pck(self._mlist, self._pckdict)
+                text = getUtility(ITemplateLoader).get(newvar, self._mlist)
+                self.assertEqual(
+                    text, expected_text,
+                    'Old variables were not converted for %s' % newvar)
+            self.assertEqual(serr.getvalue(),
+                             'Unable to convert mailing list attribute: '
+                             f'{oldvar} with value "UNIT TESTING '
+                             '${display_name} mailing list -- ${listname}\n'
+                             '%(web_page_url)slistinfo/"\n')
+            serr.close()
+
+    def test_no_unconverted_issues_no_message(self):
+        test_text = ('UNIT TESTING %(real_name)s mailing list\n'
+                     'List description: %(description)s')
+        expected_text = ('UNIT TESTING ${display_name} mailing list '
+                         '-- ${listname}\n'
+                         'List description: ${description}')
+        for oldvar, newvar in self._conf_mapping.items():
+            serr = StringIO()
+            with redirect_stderr(serr):
+                self._pckdict[str(oldvar)] = str(test_text)
+                import_config_pck(self._mlist, self._pckdict)
+                text = getUtility(ITemplateLoader).get(newvar, self._mlist)
+                self.assertEqual(
+                    text, expected_text,
+                    'Old variables were not converted for %s' % newvar)
+            self.assertEqual(serr.getvalue(), '')
+            serr.close()
+
     def test_drop_listinfo_if_contains_crs(self):
         self._pckdict = dict(msg_footer=(
             '_______________________________________________\r\n'
@@ -1130,6 +1225,21 @@ class TestRosterImport(unittest.TestCase):
         member = self._mlist.members.get_member('bob@example.com')
         self.assertEqual(member.user, user)
 
+    def test_owner_and_moderator_delivery_enabled(self):
+        # If an owner or moderator is a member with delivery disabled, the
+        # imported owner/moderator must have delivery enabled.
+        # Set anne and bob's delivery status disabled by user.
+        self._pckdict['delivery_status'] = {
+            'anne@example.com': (2, 1612366744.399534),
+            'bob@example.com': (2, 1612366744.399534)}
+        import_config_pck(self._mlist, self._pckdict)
+        self.assertEqual(
+            self._mlist.owners.get_member('anne@example.com').delivery_status,
+            DeliveryStatus.enabled)
+        self.assertEqual(
+            self._mlist.moderators.get_member('bob@example.com').
+            delivery_status, DeliveryStatus.enabled)
+
     def test_owner_and_moderator_not_lowercase(self):
         # In the v2.1 pickled dict, the owner and moderator lists are not
         # necessarily lowercased already.
